<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pam">
<context>
    <name>App.About</name>
    <message>
        <location filename="../main.cpp" line="92"/>
        <source>System Monitor</source>
        <translation>Pamantawag nga Sistema</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="82"/>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>Pamantawag nga sistema amo an tool para monitorar an load nga sistema ha tiempo real, tingan ngan kontrola an mga proseso ngan serbisyo nga nangunguna ha imo sistema.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="28"/>
        <source>Hide details</source>
        <translation>I-hide an mga detalye</translation>
    </message>
    <message>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="39"/>
        <source>Overall utilization</source>
        <translation>Pangkabug-os nga paggamit</translation>
    </message>
    <message>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="42"/>
        <source>Individual utilization</source>
        <translation>Pang-individual nga paggamit</translation>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <location filename="../gui/block_dev_item_widget.cpp" line="138"/>
        <source>Read</source>
        <translation>I-read</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_item_widget.cpp" line="142"/>
        <source>Write</source>
        <translation>I-write</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <location filename="../gui/cpu_detail_widget.cpp" line="154"/>
        <source>60 seconds</source>
        <translation>60 segundo</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <location filename="../model/cpu_info_model.cpp" line="43"/>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 adlaw %2 oras %3 minuto</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="91"/>
        <source>Utilization</source>
        <translation>Paggamit</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="93"/>
        <source>Frequency</source>
        <translation>Average frequency</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="98"/>
        <source>Max frequency</source>
        <translation>Frequency</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="100"/>
        <source>Average frequency</source>
        <translation>Average frequency</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="104"/>
        <source>Up time</source>
        <translation>Kasamtangan nga oras</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="106"/>
        <source>Sockets</source>
        <translation>Sockets</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="110"/>
        <source>Logical processors</source>
        <translation>Mga logical processor</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="112"/>
        <source>Virtualization</source>
        <translation>Virtualization</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="116"/>
        <source>L1i cache</source>
        <translation>L1i cache</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="118"/>
        <source>L1d cache</source>
        <translation>L1d cache</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="122"/>
        <source>L2 cache</source>
        <translation>L2 cache</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="124"/>
        <source>L3 cache</source>
        <translation>L3 cache</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="128"/>
        <source>Load average</source>
        <translation>Kasamtangan nga load</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="130"/>
        <source>File descriptors</source>
        <translation>Mga file descriptors</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="134"/>
        <source>Processes</source>
        <translation>Processes</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="136"/>
        <source>Threads</source>
        <translation>Mga threads</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="140"/>
        <source>Host name</source>
        <translation>Host name</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="142"/>
        <source>OS type</source>
        <translation>Tipo han OS</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="146"/>
        <source>Version</source>
        <translation>Versyon</translation>
    </message>
</context>
<context>
    <name>Cancel</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="298"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancel</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <location filename="../gui/chart_view_widget.cpp" line="293"/>
        <source>60 seconds</source>
        <translation>60 segundo</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="477"/>
        <source>No search results</source>
        <translation>Wala an mga resulta han pagbukas</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <location filename="../compact_cpu_monitor.cpp" line="87"/>
        <source>Details</source>
        <translation>Mga detalye</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <location filename="../cpu_monitor.cpp" line="70"/>
        <source>Details</source>
        <translation>Mga detalye</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="165"/>
        <source>active</source>
        <translation>nag-activate</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="167"/>
        <source>reloading</source>
        <translation>nag-reload</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="169"/>
        <source>inactive</source>
        <translation>nag-inactivate</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="170"/>
        <source>failed</source>
        <translation>nag-fail</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="172"/>
        <source>activating</source>
        <translation>nag-activate</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="174"/>
        <source>deactivating</source>
        <translation>nag-deactivate</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="146"/>
        <source>stub</source>
        <translation>stub</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="149"/>
        <source>not-found</source>
        <translation>nag-identify</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="151"/>
        <source>bad-setting</source>
        <translation>nag-setting</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="152"/>
        <source>error</source>
        <translation>nag-error</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="153"/>
        <source>merged</source>
        <translation>nag-merge</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="154"/>
        <source>masked</source>
        <translation>nag-mask</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="147"/>
        <source>loaded</source>
        <translation>nag-load</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="297"/>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="295"/>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="296"/>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="274"/>
        <source>enabled</source>
        <translation>nag-enable</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="275"/>
        <source>disabled</source>
        <translation>nag-disable</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="276"/>
        <source>static</source>
        <translation>nag-static</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="277"/>
        <source>transient</source>
        <translation>nag-transient</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="278"/>
        <source>indirect</source>
        <translation>nag-indirect</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="280"/>
        <source>enabled-runtime</source>
        <translation>nag-enable-runtime</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="281"/>
        <source>masked</source>
        <translation>nag-mask</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="283"/>
        <source>generated</source>
        <translation>nag-generate</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="217"/>
        <source>dead</source>
        <translation>dead</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="219"/>
        <source>start-pre</source>
        <translation>start-pre</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="221"/>
        <source>start</source>
        <translation>start</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="223"/>
        <source>start-post</source>
        <translation>start-post</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="225"/>
        <source>running</source>
        <translation>running</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="227"/>
        <source>exited</source>
        <translation>exited</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="229"/>
        <source>reload</source>
        <translation>pangunahin</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="231"/>
        <source>stop</source>
        <translation>pangunahin</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="233"/>
        <source>stop-watchdog</source>
        <translation>pangunahin</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="235"/>
        <source>stop-sigterm</source>
        <translation>pangunahin</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="237"/>
        <source>stop-sigkill</source>
        <translation>pangunahin</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="239"/>
        <source>stop-post</source>
        <translation>pangunahin</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="241"/>
        <source>final-sigterm</source>
        <translation>pangunahin</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="243"/>
        <source>final-sigkill</source>
        <translation>pangunahin</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="245"/>
        <source>failed</source>
        <translation>nagkakasala</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="247"/>
        <source>auto-restart</source>
        <translation>otomatikong pagsimula</translation>
    </message>
</context>
<context>
    <name>DBusAlarmNotify</name>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="38"/>
        <source>Warning</source>
        <translation>Pangungusap</translation>
    </message>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="39"/>
        <source>Your CPU usage is higher than %1%!</source>
        <translation>Ang iyong paggamit ng CPU ay mas mataas kaysa sa %1%!</translation>
    </message>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="51"/>
        <source>Your memory usage is higher than %1%!</source>
        <translation>Ang iyong paggamit ng memorya ay mas mataas kaysa sa %1%!</translation>
    </message>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="71"/>
        <source>View</source>
        <translation type="unfinished">View</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="62"/>
        <source>Used</source>
        <translation>Ginamit</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="64"/>
        <source>Available</source>
        <translation>Nagagamit</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="68"/>
        <source>Shared</source>
        <translation>Sinambit</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="70"/>
        <source>Cached</source>
        <translation>Nakalagay</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="74"/>
        <source>Buffers</source>
        <translation>Mga buffer</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="76"/>
        <source>Cached swap</source>
        <translation>Nakalagay na swap</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="80"/>
        <source>Active</source>
        <translation type="unfinished">Active</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="82"/>
        <source>Inactive</source>
        <translation>Wala nang aktibo</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="86"/>
        <source>Dirty</source>
        <translation>Mapait</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="88"/>
        <source>Mapped</source>
        <translation>Nakakalat</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="92"/>
        <source>Total swap</source>
        <translation>Kabuuang swap</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="94"/>
        <source>Free swap</source>
        <translation>Libre na swap</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="98"/>
        <source>Slab</source>
        <translation>Slab</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="64"/>
        <source>Model</source>
        <translation>Modelo</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="66"/>
        <source>Read speed</source>
        <translation>Layo ng bilis</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="70"/>
        <source>Write speed</source>
        <translation>Bilis ng pagbubuo</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="72"/>
        <source>Capacity</source>
        <translation>Kabug-os</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="76"/>
        <source>Sectors read</source>
        <translation>Sectors na binasa</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="78"/>
        <source>Reads/s</source>
        <translation>Pagbasa/s</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="82"/>
        <source>Sectors read/s</source>
        <translation>Sektors pagbasa/s</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="84"/>
        <source>Reads merged/s</source>
        <translation>Pagbasa nga sinugdanan/s</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="88"/>
        <source>Sectors written</source>
        <translation>Sektors nakasulat</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="90"/>
        <source>Writes completed </source>
        <translation>Nakasulat nga tapos </translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="94"/>
        <source>Writes merged</source>
        <translation>Nakasulat nga sinugdanan</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="96"/>
        <source>Writes/s</source>
        <translation>Nakasulat/s</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="100"/>
        <source>Sectors written/s</source>
        <translation>Sektors nakasulat/s</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="102"/>
        <source>Writes merged/s</source>
        <translation>Nakasulat nga sinugdanan/s</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <location filename="../gui/dialog/error_dialog.cpp" line="68"/>
        <source>OK</source>
        <comment>button</comment>
        <translation type="unfinished">OK</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <location filename="../common/common.cpp" line="28"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="34"/>
        <source>Display shortcuts</source>
        <translation>Ipakita ang mga shortcut</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="166"/>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Pangako nga proseso ay maaaring magresulta ng pagkawala ng datos.
Sigurado ka bang nangako mong iwanan ito?</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="510"/>
        <source>End process</source>
        <translation>Tapos ang proseso</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="367"/>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Pangako nga proseso ay maaaring magresulta ng pagkawala ng datos.
Sigurado ka bang nangako mong iwanan ito?</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="511"/>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Pangako nga aplikasyon ay maaaring magresulta ng pagkawala ng datos.
Sigurado ka bang nangako mong iwanan ito?</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="519"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished">Cancel</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="520"/>
        <source>Force End</source>
        <comment>button</comment>
        <translation type="unfinished">Force End</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="173"/>
        <source>End</source>
        <comment>button</comment>
        <translation type="unfinished">End</translation>
    </message>
</context>
<context>
    <name>Logout</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="299"/>
        <source>Logout</source>
        <translation>Logout</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../gui/main_window.cpp" line="172"/>
        <source>Settings</source>
        <translation>Pangkabahayan</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <location filename="../gui/mem_stat_view_widget.cpp" line="47"/>
        <source>Size</source>
        <translation>Layo</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="157"/>
        <source>IP address:</source>
        <translation>IP address:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="157"/>
        <source>Netmask:</source>
        <translation>Netmask:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="157"/>
        <source>Broadcast:</source>
        <translation>Broadcast:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="159"/>
        <source>Prefixlen:</source>
        <translation>Prefixlen:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="159"/>
        <source>Scope:</source>
        <translation>Scope:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="293"/>
        <source>Connection type</source>
        <translation>Uri ng koneksyon</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="301"/>
        <source>ESSID</source>
        <translation>ESSID</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="307"/>
        <source>Link quality</source>
        <translation>Kalidad ng link</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="312"/>
        <source>Signal strength</source>
        <translation>Kahusayan ng tanda</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="317"/>
        <source>Noise level</source>
        <translation>Antas ng noise</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="323"/>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="328"/>
        <source>Bandwidth</source>
        <translation>Bandwidth</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="333"/>
        <source>RX packets</source>
        <translation>RX packets</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="338"/>
        <source>RX bytes</source>
        <translation>RX bytes</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="343"/>
        <source>RX errors</source>
        <translation>RX errors</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="348"/>
        <source>RX dropped</source>
        <translation>RX dropped</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="353"/>
        <source>RX overruns</source>
        <translation>RX overruns</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="358"/>
        <source>RX frame</source>
        <translation>RX frame</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="363"/>
        <source>TX packets</source>
        <translation>TX packets</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="368"/>
        <source>TX bytes</source>
        <translation>TX bytes</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="373"/>
        <source>TX errors</source>
        <translation>TX errors</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="383"/>
        <source>TX overruns</source>
        <translation>TX overruns</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="388"/>
        <source>TX carrier</source>
        <translation>TX carrier</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="267"/>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="282"/>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="378"/>
        <source>TX dropped</source>
        <translation>TX dropped</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <location filename="../gui/process_attribute_dialog.cpp" line="140"/>
        <source>Command line</source>
        <translation>Command line</translation>
    </message>
    <message>
        <location filename="../gui/process_attribute_dialog.cpp" line="145"/>
        <source>Start time</source>
        <translation>Start time</translation>
    </message>
    <message>
        <location filename="../gui/process_attribute_dialog.cpp" line="135"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <location filename="../gui/xwin_kill_preview_background_widget.cpp" line="146"/>
        <source>Click the application you want to end</source>
        <translation>Click the application you want to end</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <location filename="../gui/detail_view_stacked_widget.cpp" line="144"/>
        <source>Memory</source>
        <translation>Memory</translation>
    </message>
    <message>
        <location filename="../gui/netif_item_view_widget.cpp" line="89"/>
        <source>Receive</source>
        <translation>Receive</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <location filename="../compact_cpu_monitor.cpp" line="220"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../compact_disk_monitor.cpp" line="145"/>
        <source>Disk read</source>
        <translation>Disk read</translation>
    </message>
    <message>
        <location filename="../compact_disk_monitor.cpp" line="146"/>
        <source>Disk write</source>
        <translation>Disk write</translation>
    </message>
    <message>
        <location filename="../compact_memory_monitor.cpp" line="176"/>
        <source>Memory</source>
        <translation>Memory</translation>
    </message>
    <message>
        <location filename="../compact_memory_monitor.cpp" line="187"/>
        <source>Swap</source>
        <translation>Swap</translation>
    </message>
    <message>
        <location filename="../compact_memory_monitor.cpp" line="188"/>
        <source>Not enabled</source>
        <translation>Not enabled</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="152"/>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="157"/>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
    <message>
        <location filename="../gui/detail_view_stacked_widget.cpp" line="145"/>
        <source>Network</source>
        <translation>Network</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="154"/>
        <source>Total Received</source>
        <translation>Total Received</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="159"/>
        <source>Total Sent</source>
        <translation>Total Sent</translation>
    </message>
    <message>
        <location filename="../gui/netif_item_view_widget.cpp" line="98"/>
        <source>Send</source>
        <translation>Ipadar</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_detail_view_widget.cpp" line="17"/>
        <source>Disks</source>
        <translation>Disk</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="67"/>
        <source>Loading</source>
        <translation>Nagloload</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="615"/>
        <source>Very high</source>
        <translation>Mga mataas</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="623"/>
        <source>High</source>
        <translation>Mataas</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="631"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="639"/>
        <source>Low</source>
        <translation>Mababa</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="647"/>
        <source>Very low</source>
        <translation>Mga mababa</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="655"/>
        <source>Custom</source>
        <translation>Custom</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="60"/>
        <source>Invalid</source>
        <translation>Invalid</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="179"/>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1, Error: [%2] %3</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="138"/>
        <source>Failed to change process priority</source>
        <translation>Nagkakasala ang pagbabago ng prioridad ng proseso</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="61"/>
        <source>Applications</source>
        <translation>Aplikasyon</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="63"/>
        <source>My processes</source>
        <translation>Mga proseso ko</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="65"/>
        <source>All processes</source>
        <translation>Mga proseso</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <location filename="../process/process_db.cpp" line="246"/>
        <source>Failed to pause process</source>
        <translation>Nagkakasala ang pag-iilaw ng proseso</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="249"/>
        <source>Failed to resume process</source>
        <translation>Nagkakasala ang pagbawi ng proseso</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="252"/>
        <source>Failed to kill process</source>
        <translation>Nagkakasala ang pag-ibayu ng proseso</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="255"/>
        <source>Unknown error</source>
        <translation>Di malayong error</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="311"/>
        <source>Failed in sending signal to process</source>
        <translation>Nagkakasala ang pagpapadala ng signal sa proseso</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="243"/>
        <source>Failed to end process</source>
        <translation>Nagkakasala ang pagtatapos ng proseso</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="58"/>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(%1 aplikasyon ng %2 proseso ang naglalaban)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <location filename="../model/process_table_model.cpp" line="240"/>
        <source>No response</source>
        <translation>Wala pang response</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.cpp" line="245"/>
        <source>Suspend</source>
        <translation>Iilaw</translation>
    </message>
    <message>
        <location filename="../process/process_name.cpp" line="82"/>
        <source>Tray</source>
        <translation>Tray</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="662"/>
        <source>View command location</source>
        <translation>Pananatili ang lokasyon ng komando</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="79"/>
        <source>Properties</source>
        <translation>Mga katangian</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="62"/>
        <source>End process</source>
        <translation>Tapos ang proseso</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="74"/>
        <source>Resume process</source>
        <translation>Bawi ang proseso</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="85"/>
        <source>Kill process</source>
        <translation>Pangunahon an proseso</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="609"/>
        <source>Change priority</source>
        <translation>Bag-o an prioridad</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="68"/>
        <source>Suspend process</source>
        <translation>Pangungusap an proseso</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="1024"/>
        <source>Custom Priority</source>
        <translation>Custom Prioridad</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="1056"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished">Cancel</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="1058"/>
        <source>Change</source>
        <comment>button</comment>
        <translation type="unfinished">Change</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <location filename="../model/process_table_model.h" line="16"/>
        <source>Name</source>
        <translation>Pangalan</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="18"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="22"/>
        <source>Memory</source>
        <translation>Memorya</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="32"/>
        <source>Disk write</source>
        <translation>Pagsulat sa Disk</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="30"/>
        <source>Disk read</source>
        <translation>Pagbasa sa Disk</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="28"/>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="26"/>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="34"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="20"/>
        <source>User</source>
        <translation>Mga Gumagamit</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="36"/>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="38"/>
        <source>Priority</source>
        <translation>Prioridad</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="23"/>
        <source>Shared memory</source>
        <translation>Kabugtang Memorya</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="24"/>
        <source>Virtual memory</source>
        <translation>Virtual Memorya</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../system/cpu_set.cpp" line="366"/>
        <source>Not support</source>
        <translation>Di mapanatag</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="10"/>
        <source>Settings</source>
        <translation>Mga Pagpipilian</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="11"/>
        <source>System Protection</source>
        <translation>Pananatag sa Sistem</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="12"/>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>Ipakita an mga babala kon ang paggamit ay nasa ibayong antas</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="13"/>
        <source>CPU warning threshold (%)</source>
        <translation>Antas ng babala sa CPU (%) </translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="14"/>
        <source>Memory warning threshold (%)</source>
        <translation>Antas ng babala sa Memorya (%) </translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="15"/>
        <source>Warning interval (min)</source>
        <translation>Mga panahon ng babala (min)</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="16"/>
        <source>Notifications</source>
        <translation>Mga Abiso</translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <location filename="../service/service_manager.cpp" line="322"/>
        <source>Failed to set service startup type</source>
        <translation>Nagkabigo an pagpapalagay sa uri ng pagpapatupad sa serbisyo</translation>
    </message>
    <message>
        <location filename="../service/service_manager.cpp" line="388"/>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Error: Nagkabigo an pagpapalagay sa uri ng pagpapatupad sa serbisyo dahil sa nangungusap na sub-proseso.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="150"/>
        <source>Service instance name</source>
        <translation>Pangalan sa instance sa serbisyo</translation>
    </message>
    <message>
        <location filename="../gui/service_name_sub_input_dialog.cpp" line="34"/>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <location filename="../gui/service_name_sub_input_dialog.cpp" line="35"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancel</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="114"/>
        <source>Refresh</source>
        <translation>Pangunahon</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="99"/>
        <source>Start</source>
        <translation>Pangunahon</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="104"/>
        <source>Stop</source>
        <translation>Pusot</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="109"/>
        <source>Restart</source>
        <translation>Pusot uli</translation>
    </message>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="537"/>
        <source>Auto</source>
        <translation>Awtomatiko</translation>
    </message>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="538"/>
        <source>Manual</source>
        <translation>Manwal</translation>
    </message>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="536"/>
        <source>Startup type</source>
        <translation>Uri han pag-awit</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <location filename="../model/system_service_table_model.h" line="16"/>
        <source>Name</source>
        <translation>Pangalan</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="18"/>
        <source>Load</source>
        <translation>Mag-load</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="23"/>
        <source>Sub</source>
        <translation>Sub</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="30"/>
        <source>Description</source>
        <translation>Paglalarawan</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="32"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="27"/>
        <source>Startup Type</source>
        <translation>Uri han pag-awit</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="21"/>
        <source>Start State</source>
        <translation>Estado han pag-awit</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="25"/>
        <source>Start Tactic</source>
        <translation>Taktika han pag-awit</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="124"/>
        <source>Settings</source>
        <translation>Mga Pagpapasiya</translation>
    </message>
    <message>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="156"/>
        <source>(Modifiable)</source>
        <translation>(Mga Paggamit)</translation>
    </message>
    <message>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="263"/>
        <source>Range: %1-%2</source>
        <translation>Ranggo: %1-%2</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="55"/>
        <source>Force end application</source>
        <translation>Forse end aplikasyon</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="140"/>
        <source>Expand</source>
        <translation>Pangalapad</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="143"/>
        <source>Compact</source>
        <translation>Pangalapad</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="135"/>
        <source>View</source>
        <translation>Mangita</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <location filename="../common/common.cpp" line="40"/>
        <source>Search</source>
        <translation>Mangita</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <location filename="../common/common.cpp" line="49"/>
        <source>Processes</source>
        <translation>Mga Proseso</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="94"/>
        <source>Services</source>
        <translation>Mga Serbisyo</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="234"/>
        <source>Users</source>
        <translation>Mga Gumagamit</translation>
    </message>
</context>
<context>
    <name>User.Account.Operation</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="97"/>
        <source>Edit account information</source>
        <translation>Bag-o an impormasyon han akawnt</translation>
    </message>
</context>
<context>
    <name>User.Account.Type</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="145"/>
        <source>Administrator</source>
        <translation>Administrator</translation>
    </message>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="145"/>
        <source>Standard User</source>
        <translation>Standard User</translation>
    </message>
</context>
</TS>
